ad_library {

	Library for Mash Ups

    @author Hamilton Chua (ham@solutiongrove.com)
    @creation-date 2006-03-04
}

namespace eval mashup { }

ad_proc -private mashup::get_package_id  {

} {
	Return the package_id of the installed and mounted mashup packge

	@author Hamilton Chua (ham@solutiongrove.com)	
	@creation-date 2006-03-05
	@return 

	@error 

} {
	return [apm_package_id_from_key "mashups"]
}

ad_proc -public mashup::get_url  {

} {
	Return the URL to the mounted mashup packge instance

	@author Hamilton Chua (ham@solutiongrove.com)	
	@creation-date 2006-03-05
	@return 

	@error 

} {
	return [apm_package_url_from_id [mashup::get_package_id]]
}

ad_proc -private mashup::type_id {
	-type
} {
	Returns the type_id from the type
} {
	return [db_string "gettypeid" "select id from mashup_portal_type where type=:type"]
}

ad_proc -private mashup::name_from_type_id {
	-type_id
} {
	Returns the type_id from the type
} {
	return [db_string "gettypename" "select type from mashup_portal_type where id=:type_id"]
}

ad_proc -private mashup::type_id_from_name {
	-name
} {
	Returns the type name from the type_id
} {
	return [db_string "gettypeid" "select id from mashup_portal_type where type=:name"]
}

ad_proc -public mashup::newportlet  {
	-user_id
	-type
	-content_id
	{-title ""}
	{-type_id ""}
	{-type ""}
	{-column_n "3"}
} {
	Creates a new portlet.
} {
	# set order_n [expr [db_string "getlastid" "select max(order_n) from mashup_portals where column_n=:column_n"] +1]
	db_dml "updateorder" "update mashup_portals set order_n=order_n+1 where column_n=:column_n"
	set order_n 1
	set id [db_nextval "mashup_portals_id"]
	if { ![exists_and_not_null type_id] && [exists_and_not_null type] } { 
		set type_id [mashup::type_id -type $type]
	}
	db_dml "insertportlet" "insert into mashup_portals (id,user_id,type_id,title,content_id,column_n,order_n,hidden_p,min_p) values (:id,:user_id,:type_id,:title,:content_id,:column_n,:order_n,'f','f')"
	return $id
}

ad_proc -public mashup::delportlet  {
	-id
} {
	Deletes a new portlet.
} {
	if { [db_0or1row "findportlet" "select content_id, type_id, user_id from mashup_portals where id=:id"] } {
		switch $type_id {
			1 {
				mashup::newsfeed::del -user_id $user_id -id $content_id
			}
			2 {
				mashup::tagcloud::del -user_id $user_id -id $content_id
			}
			3 {
				mashup::weather::del -user_id $user_id -id $content_id
			}
			4 {
				# no need to do anything for geoip
			}
			5 {
				# no need to do anything for xocontent
			}
			6 {
				# nothing needs to be done for google ads
			}
		}
		db_dml "deleteportlet" "delete from mashup_portals where id=:id"
	}
}

ad_proc -public mashup::delportletall  {
	-user_id
} {
	Deletes all of a given user's portlet
} {
	db_foreach "getuserportlets" "select id from mashup_portals where user_id=:user_id" {
		mashup::delportlet -id $id
	}
}

ad_proc -public mashup::user_is_registered {
	-user_id
} {
	Is this user regsitered or just a session id generated by checknewuser.
} {
	if { [db_0or1row "userexists" "select registered from mashup_user where user_id=:user_id"] } {
		return $registered
	}
	return 0
}

ad_proc -private mashup::getuserid {

} {
	Checks if the current user is logged in.
	If LOGGED IN :
		just use ad_conn and get the user_id and return it
	If NOT LOGGED IN :
		check if there is an existing cookie with session id
		YES, there is :
			retrieve and return the session id
		NO, there is none :
			get the next integer in the object_id sequence
			create a cookie with this id, this id is also our session id
			clone the portlets of an existing user
} {
	set user_id [ad_conn user_id]
	if { $user_id == 0 } {
		# user is not logged in 
		set user_session_id [ad_get_client_property "mashup" "user_session_id"]
		if { ${user_session_id} == "" } {
			set user_session_id [db_nextval acs_object_id_seq]
			ad_set_client_property "mashup" "user_session_id" $user_session_id
			
		}
		return $user_session_id
	} else {
		# user is logged in
		return $user_id
	}
}

ad_proc -private mashup::checkfornewuser {

} {
	Call mashup::getuserid to retrieve a user_id.
	If user_id already exists, just return the user_id.
	If user_id does NOT exist, attempt to clone a user's portal to create the new user's portal
	Returns the user_id
} {
	# get the user_id
	set user_id [mashup::getuserid]
	# does the user id exist in mashup user table
	if { ![db_0or1row "userexists" "select user_id from mashup_user where user_id=:user_id"] } {
		# no, create a user and clone
		db_dml "inserttitle" "insert into mashup_user (user_id, page_title) values (:user_id, 'Solution Grove Web 2.0 Demo (click here) ')"
		mashup::userclone -source_user_id 0 -target_user_id $user_id
	}
	return $user_id
}


ad_proc -private mashup::userclone {
	-source_user_id
	-target_user_id
} {
	Create a clone of a user's mashup portal
} {
	if { ![db_0or1row "userexists" "select * from mashup_user where user_id=:target_user_id"]} {
		db_dml "inserttitle" "insert into mashup_user (user_id, page_title, registered) values (:target_user_id, 'Click me and make this page yours ...', 1)"
	}
	db_foreach "getsource" "select column_n, title, type_id, content_id from mashup_portals where user_id=:source_user_id" {
		switch $type_id {
			1 {
				set source_id [db_string "getsourceid" "select source_id from mashup_feeds where id=:content_id"]
				set content_id [mashup::newsfeed::new -user_id $target_user_id -source_id $source_id]
			}
			2 {
				set cloud_name [db_string "getcloudname" "select cloud_name from tagcloud where id=:content_id"]
				set content_id [mashup::tagcloud::new -user_id $target_user_id -cloud_name $cloud_name]
			}
			3 {
				set yw_code [db_string "getloccode" "select yw_code from mashup_weather where id=:content_id"]
				set content_id [mashup::weather::new -user_id $target_user_id -yw_code $yw_code]
			}
			4 {
				# nothing to do for geoip
			}
			5 {	
				# nothing to do for content
			}
			6 {
				# nothing to do for google ads
			}
		}
		mashup::newportlet -user_id $target_user_id -type_id $type_id -title $title -content_id $content_id -column_n $column_n
	}
}

ad_proc -private mashup::userdel {
	-user_id
} {
	Deletes all the portlets in a user's mashup portal.
	Deletes the user's entry in the mashup users table
} {
	mashup::delportletall -user_id $user_id
	mashup::newsfeed::delall -user_id $user_id
	mashup::tagcloud::delall -user_id $user_id
	db_dml "deluser" "delete from mashup_user where user_id=:user_id"
}

ad_proc -private mashup::cleanup_unregistered {

} {
	Deletes all mashup users whose state is unregistered
} {
	ns_log Notice "HAM : Running Scheduled Proc to remove unregistered users from mashup"
	db_foreach "getunregistered" "select user_id from mashup_user where registered=0" {
		mashup::userdel -user_id $user_id
	}
}