# /packages/mashups/www/portal.tcl

ad_page_contract {
  
  Show the Mashups Page
  
  @author Hamilton Chua (ham@solutiongrove.com)
  @date 2006-08-08
  
}

# mashups landing page url
set mashup_url [mashup::get_url]

# google api key
set google_api_key [parameter::get -parameter "GoogleApiKey"]

# url to ajax helper
set ah_url [ah::get_url]

# user_id = 0 means no one is logged in
# always check for user_id 0
set user_id [mashup::checkfornewuser]
set loggedin_p [ad_conn user_id]

# is the user site wide admin
set swa_p [acs_user::site_wide_admin_p]

# get number of users online
set num_users_online [lc_numeric [whos_online::num_users]]

# default title
set title "Solution Grove's Web 2 Demo (click here)"

# load javascript sources
set ah_sources [ah::js_sources -source "default"]
append ah_sources [ah::yui::js_sources -source "default,event"]

set scripts ""

# ********* User/Portal Info ******* #

# retrieve the user's preferences for the page, 
#  override existing vars as necessary
db_0or1row "get_mashup_user" "select page_title from mashup_user where user_id=:user_id"

# retrieve the portal_ids
db_multirow colitems colitems { select a.*,b.type 
				from mashup_portals a, 
					mashup_portal_type b 
				where a.type_id = b.id 
				and user_id=:user_id order by column_n,order_n }

# ********* Javascript ************ #

# initilize page

append scripts "function initPage() {"
append scripts [ah::effects -element "loading" -effect "Fade" -options "afterFinish:function() { setup(); } " ]
append scripts "} "

append scripts "function setup() { "
append scripts [ah::effects -element "page" -effect "Appear"]
append scripts "loadUserBar(); resetSortables(); "
# allow users to edit the title of the page
append scripts "new Ajax.InPlaceEditor( 'titlecontent', '${mashup_url}xmlhttp/titlerename', {cols:40,callback: function(form,value) { return 'title=' + escape(value) }} ); "
# make the admindiv draggable
append scripts [ah::draggable -element "adminportlet"]
# make map container draggable
append scripts [ah::draggable -element "mapcontainer"]
append scripts [ah::yui::addlistener -element "addstuffbutton" -event "click" -callback "function() { toggleadminportlet(); }"]
append scripts "} "

# make the divs in the 3 columns sortable
append scripts "function resetSortables () { "
set sortable_ajax [ah::ajaxrequest -url "${mashup_url}xmlhttp/sort-portlets" -pars "Sortable.serialize(sortable)" ]
set sortable_options "dropOnEmpty:true,hoverclass:'dropHover',handle:'portlet-title',tag:'div',only:'portlet',overlap:'horizontal',containment:\['column1','column2','column3'\],constraint:false,ghosting:false,floating:false,onUpdate:function(sortable){ $sortable_ajax }" 
append scripts [ah::sortable -element "column1" -options $sortable_options ]
append scripts [ah::sortable -element "column2" -options $sortable_options ]
append scripts [ah::sortable -element "column3" -options $sortable_options ]
append scripts "} "

# load the userbar
append scripts "function loadUserBar () {"
append scripts [ah::ajaxupdate -container "userbar" -url "${mashup_url}xmlhttp/userbar"]
append scripts "} "

# function to show/hide elements
append scripts "function toggle_el(element) { "
append scripts [ah::toggle -element "element" -options "duration:'0.5'" -element_is_var] 
append scripts "} "

# function to show/hide add stuff portlet
append scripts "function toggleadminportlet(){ "
append scripts "updateadminportlet();"
append scripts "toggle_el('adminportlet');"
append scripts "} "

# function that updates the contents of the admin portlet
append scripts "function updateadminportlet() {"
append scripts [ah::ajaxupdate -container "adminportlet" -url "${mashup_url}xmlhttp/addstuff"]
append scripts "} "

# generic function to add a portlet
#  this function should accept a type and reference
#  reference is something specific to the type
#  the function will process any validation necessary depending on type
append scripts "function addPortlet(type,reference) {"
append scripts [ah::ajaxrequest -url "${mashup_url}xmlhttp/newportlet" \
		-pars "'type='+type+'&reference='+reference" \
		-options "onSuccess:function(t){ showNewPortlet(t.responseText); }, onFailure:function(t) { alert('We encountered a problem adding your portlet. Please try again later.'); }, evalScripts:true"]
append scripts "} "

# render the new portlet, called from addPortlet
append scripts "function showNewPortlet(content) {"
append scripts "colbody = document.getElementById(\"column3\");"
append scripts "colbody.innerHTML=content+colbody.innerHTML;"
append scripts "new Effect.Grow(colbody.getElementsByTagName(\"div\").item(0),{duration:1.5,direction:'bottom-left'});"
append scripts "resetSortables(); }"

# function to remove a portlet
append scripts "function delPortlet(portlet) { "
append scripts "input_box=confirm(\"Are you sure you want to remove this portlet ?\"); "
append scripts "if (input_box==true) { "
append scripts "var thisnode=document.getElementById(portlet); "
append scripts "var parentnode=thisnode.parentNode; "
append clean_portlet_script [ah::ajaxrequest -url "${mashup_url}xmlhttp/delportlet" \
				-pars "'portlet='+portlet" \
				-options "onSuccess:function(o){ parentnode.removeChild(thisnode); updateadminportlet(); resetSortables(); } "]
append scripts [ah::effects -element "thisnode" -element_is_var -effect "Shrink" -options "duration:1.0,direction:'center',afterFinish:function(){ $clean_portlet_script }" ]
append scripts "} }"

# function to show a map
append scripts "function showmylocation(id) {"
set showuserloc [ah::ajaxrequest -url "${mashup_url}xmlhttp/map" \
				-pars "'id='+id+'&type=mylocation&container=map'" \
				-options "onSuccess:function (t) { eval(t.responseText); }"]
append scripts "new Effect.Appear('mapcontainer',{afterFinish:function() { $showuserloc } });"
append scripts "} "

# function to show visitors on the map
append scripts "function showallvisitors() { "
append scripts [ah::ajaxrequest -url "${mashup_url}xmlhttp/map" \
				-pars "'type=allvisitors&container=map'" \
				-options "onSuccess:function (t) { eval(t.responseText); }"]
append scripts "} "

# function to initiate signup
if { !$loggedin_p } {

        # cleanup and show the signup form
        append scripts "function signup_on() { "
        append scripts "\$('email').value='';"
        append scripts "\$('fnames').value='';"
        append scripts "\$('lname').value='';"
        append scripts "\$('password').value='';"
        append scripts "\$('passwordconfirm').value='';"
        append scripts "\$('screen_name').value='';"
        set signup_on_script [ah::effects -element "adminportlet" -effect "Fade" ]
        append signup_on_script [ah::effects -element "signupdiv" -effect "Appear" ]
        append signup_on_script [ah::effects -element "addstuffbutton" -effect "Fade" ]
        append signup_on_script [ah::effects -element "userbar" -effect "Fade" ]
        append scripts [ah::effects -element "page" -effect "Fade" -options "afterFinish:function(){ $signup_on_script }" ]
        append scripts "} "

        # hide signup form
        append scripts "function signup_off() { "
        set signup_off_script [ah::effects -element "addstuffbutton" -effect "Appear" ]
        append signup_off_script [ah::effects -element "page" -effect "Appear" ]
        append signup_off_script [ah::effects -element "userbar" -effect "Appear" ]
        append signup_off_script [ah::effects -element "processing" -effect "Fade"]
        append signup_off_script [ah::effects -element "formcontent" -effect "Appear"]
        append scripts [ah::effects -element "signupdiv" -effect "Fade" -options "afterFinish:function(){ $signup_off_script }" ]
        append scripts "} "

        # validate individual fields
        append scripts "function signup_field_validate(type,field) {"
        append scripts "var value = field.value;"
        append scripts "if (type == 'passwordconfirm') { "
        append scripts "if (field.value != \$('password').value ) { \$('signup_form_error').innerHTML='Password confirmation does not match.'; field.focus(); setTimeout(\" \$('signup_form_error').innerHTML='&nbsp;' \",3500); } "
        append scripts "} else { "
        append scripts [ah::ajaxrequest -url "${mashup_url}xmlhttp/validatesignup" \
                                        -pars "'type='+type+'&value='+value" \
                                        -options "onSuccess:function(o) { if (o.responseText != \"\") { \$('signup_form_error').innerHTML=o.responseText; field.focus(); setTimeout(\" \$('signup_form_error').innerHTML='&nbsp;' \",3500); } } "]
        append scripts "} } "

        append scripts "function signup_form_submit() { "
        append scripts "if ( isEmpty(\$('email')) || isEmpty(\$('fnames')) || isEmpty(\$('lname')) || isEmpty(\$('password')) || isEmpty(\$('passwordconfirm')) || isEmpty(\$('screen_name')) ) {"
        append scripts "\$('signup_form_error').innerHTML='All fields are required.'; setTimeout(\" \$('signup_form_error').innerHTML='&nbsp;' \",3500);"
        append scripts "} else {"

        set show_formcontent [ah::effects -element "formcontent" -effect "Appear" -options "duration:0.1"]
        set fail_script [ah::effects -element "processing" -effect "Fade" -options "duration:0.1,afterFinish:function(){ $show_formcontent}"]

        set submit_signup_script [ah::effects -element "processing" -effect "Appear" -options "duration:0.1"]
        append submit_signup_script [ah::ajaxrequest -url "${mashup_url}xmlhttp/register" \
                                        -pars "Form.serialize(\$('signup_form'))" \
                                        -options "onSuccess:function(o) {  } " ]

        append scripts [ah::effects -element "formcontent" -effect "Fade" -options "duration:0.1,afterFinish:function() { $submit_signup_script }"]
        append scripts "} } "

        append scripts "function isEmpty(elem){ var str = elem.value; if(str.length == 0){ return true; } else {return false;} } "
}

# initialize page on load
append scripts [ah::yui::addlistener -element "window" -event "load" -callback "function() { initPage(); }" -element_is_var]

# enclose all the javascript in script tags
set scripts [ah::enclose_in_script -script $scripts]

# record the visit
mashup::geoip::recordvisit 

